Documentation
¶
Overview ¶
Package log provides a common logging package for ACD with logging level.
Index ¶
- func Debug(v ...interface{})
- func Debugf(format string, v ...interface{})
- func Error(v ...interface{})
- func Errorf(format string, v ...interface{})
- func Fatal(v ...interface{})
- func Fatalf(format string, v ...interface{})
- func Info(v ...interface{})
- func Infof(format string, v ...interface{})
- func Levels() string
- func Print(l Level, v ...interface{})
- func Printf(l Level, format string, v ...interface{})
- func SetLevel(l Level)
- func Trace(v ...interface{})
- func Tracef(format string, v ...interface{})
- type Level
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Print ¶
func Print(l Level, v ...interface{})
Print calls Print only if the level is equal or lower than the set level. If the level is FatalLevel, it will call Fatal regardless...
Types ¶
type Level ¶
type Level uint8
Level is a custom type representing a log level.
const ( // DisableLogLevel disables logging completely. DisableLogLevel Level = iota // FatalLevel represents a fatal message. FatalLevel // ErrorLevel represents an error message. ErrorLevel // InfoLevel represents an info message. InfoLevel // DebugLevel represents a debug message. DebugLevel // DebugLevel represents a trace message. TraceLevel )
Click to show internal directories.
Click to hide internal directories.